RequestId

Struct RequestId 

pub struct RequestId(/* private fields */);
Unique identifier for a WebSocket request.

Used to correlate requests with their responses in the async protocol. Generated as UUID v4 by Rust side.

Special Values

Example

let request_id = RequestId::generate();
assert!(!request_id.is_ready());

let ready_id = RequestId::ready();
assert!(ready_id.is_ready());

Implementations

Source

impl RequestId

pub fn generate() -> Self

Generates a new random request ID.

pub const fn ready() -> Self

Returns the special READY request ID (nil UUID).

This ID is used for the initial handshake message from the extension.

pub fn is_ready(&self) -> bool

Returns true if this is the READY request ID.

pub const fn as_uuid(&self) -> &Uuid

Returns a reference to the underlying UUID.