Request and Response message types. Request and Response message types.
Defines the message format for command requests and responses between local end (Rust) and remote end (Extension).
See ARCHITECTURE.md Section 2.2-2.3 for specification.
Structs
- Request
- A command request from local end to remote end.
- Response
- A response from remote end to local end.
Enums
- Response
Type - Response type discriminator.